@@ -14,7 +14,8 @@ import tempfile
 from glob import escape, glob
 from os.path import basename, dirname, exists, join
 import os
-from warnings import warn
+import shutil
+
 try:
     from rich import print
 except Exception:
@@ -30,7 +31,7 @@ from pygments.formatters import LatexFormatter
 from code_grader.lexer import CustomJavaLexer
 
 SCORING_REGEX = re.compile(
-    r"//\s*\[(.*)\s*:\s*([0-9.,]+)\s*/\s*([0-9.,]+)\s*(point|Point|Punkten|Punkte)?s?\]")
+    r"//\s*\[(.*)\s*:\s*([0-9.,]+)\s*/\s*([0-9.,]+)\s*(point|Point|Punkten|Punkte|p.|P.)?s?\]")
 
 
 class ScoringResult:
@@ -147,7 +148,7 @@ def create_tex_file(filenames, working_dir):
 """).render(scoring.__dict__))
 
     for filename in relevant_files:
-        with open(filename, 'r'  , encoding="utf-8",errors="ignore") as f:
+        with open(filename, 'r', encoding="utf-8", errors="ignore") as f:
             code = f.read()
             doctext.append(f"\\section*{{{basename(filename)}}}")
             doctext.append(highlight(code, CustomJavaLexer(), formatter))
@@ -170,13 +171,16 @@ def create_pdf(filenames, working_dir, silent=False):
         f.write(tex_code)
         tex_file = f.name
 
-    if sys.platform in ('linux', 'darwin'):
+    if shutil.which('latexmk'):
         cmd = [
             "latexmk", "-silent", "-pdf", "-shell-escape", "-file-line-error",
             "-synctex=1", "-f", "-interaction=nonstopmode", tex_file
         ]
-    elif sys.platform == 'win32':
+    elif shutil.which('pdflatex'):
         cmd = ["pdflatex", "-shell-escape", "-interaction=nonstopmode", tex_file]
+    else:
+        print('"pdflatex" or "latexmk" need to be in $PATH!!!')
+        exit(-1)
 
     print(f"Running \"{' '.join(cmd)}\" ...")
     subprocess.call(cmd, cwd=dirname(tex_file))
